@@ -11,6 +11,7 @@ import (
 	"github.com/konveyor/openshift-velero-plugin/velero-plugins/deploymentconfig"
 	"github.com/konveyor/openshift-velero-plugin/velero-plugins/imagestream"
 	"github.com/konveyor/openshift-velero-plugin/velero-plugins/imagestreamtag"
+	"github.com/konveyor/openshift-velero-plugin/velero-plugins/imagetag"
 	"github.com/konveyor/openshift-velero-plugin/velero-plugins/job"
 	"github.com/konveyor/openshift-velero-plugin/velero-plugins/persistentvolume"
 	"github.com/konveyor/openshift-velero-plugin/velero-plugins/pod"
@@ -38,6 +39,7 @@ func main() {
 		RegisterBackupItemAction("openshift.io/03-pv-backup-plugin", newPVBackupPlugin).
 		RegisterRestoreItemAction("openshift.io/03-pv-restore-plugin", newPVRestorePlugin).
 		RegisterRestoreItemAction("openshift.io/04-pvc-restore-plugin", newPVCRestorePlugin).
+		RegisterBackupItemAction("openshift.io/04-imagestreamtag-backup-plugin", newImageStreamTagBackupPlugin).
 		RegisterRestoreItemAction("openshift.io/04-imagestreamtag-restore-plugin", newImageStreamTagRestorePlugin).
 		RegisterRestoreItemAction("openshift.io/05-route-restore-plugin", newRouteRestorePlugin).
 		RegisterRestoreItemAction("openshift.io/06-build-restore-plugin", newBuildRestorePlugin).
@@ -58,6 +60,7 @@ func main() {
 		RegisterRestoreItemAction("openshift.io/20-SCC-restore-plugin", newSCCRestorePlugin).
 		RegisterRestoreItemAction("openshift.io/21-role-bindings-restore-plugin", newRoleBindingRestorePlugin).
 		RegisterRestoreItemAction("openshift.io/22-cluster-role-bindings-restore-plugin", newClusterRoleBindingRestorePlugin).
+		//RegisterRestoreItemAction("openshift.io/23-imagetag-restore-plugin", newImageTagRestorePlugin).
 		Serve()
 }
 
@@ -169,6 +172,14 @@ func newImageStreamRestorePlugin(logger logrus.FieldLogger) (interface{}, error)
 	return &imagestream.RestorePlugin{Log: logger}, nil
 }
 
+func newImageStreamTagBackupPlugin(logger logrus.FieldLogger) (interface{}, error) {
+	return &imagestreamtag.BackupPlugin{Log: logger}, nil
+}
+
 func newImageStreamTagRestorePlugin(logger logrus.FieldLogger) (interface{}, error) {
 	return &imagestreamtag.RestorePlugin{Log: logger}, nil
 }
+
+func newImageTagRestorePlugin(logger logrus.FieldLogger) (interface{}, error) {
+	return &imagetag.RestorePlugin{Log: logger}, nil
+}
